@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.9.5 (default, May 11 2021, 08:20:37)  [GCC 10.3.0]
+# Python 3.9.7 (default, Sep 10 2021, 14:59:43)  [GCC 11.2.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -1015,92 +1015,91 @@ class oneperEnumType01_1(str, Enum):
     TOKEN='token'
 
 
-class oneperType01_1(GeneratedsSuper):
+class oneperType00_1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('username', 'xs:string', 0, 0, {'name': 'username', 'type': 'xs:string'}, None),
-        MemberSpec_('inner01', 'oneperType01_2', 0, 0, {'name': 'inner01', 'type': 'oneperType01_2'}, None),
+        MemberSpec_('inner01', 'oneperType01_1', 0, 0, {'name': 'inner01', 'type': 'oneperType01_1'}, None),
+        MemberSpec_('inner02', 'oneperType01_2', 0, 0, {'name': 'inner02', 'type': 'oneperType01_2'}, None),
     ]
     subclass = None
     superclass = None
-    def __init__(self, username=None, inner01=None, gds_collector_=None, **kwargs_):
+    def __init__(self, inner01=None, inner02=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
         self.gds_elementtree_node_ = None
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        self.username = username
-        self.username_nsprefix_ = None
         self.inner01 = inner01
         self.inner01_nsprefix_ = None
+        self.inner02 = inner02
+        self.inner02_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, oneperType01_1)
+                CurrentSubclassModule_, oneperType00_1)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if oneperType01_1.subclass:
-            return oneperType01_1.subclass(*args_, **kwargs_)
+        if oneperType00_1.subclass:
+            return oneperType00_1.subclass(*args_, **kwargs_)
         else:
-            return oneperType01_1(*args_, **kwargs_)
+            return oneperType00_1(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
     def set_ns_prefix_(self, ns_prefix):
         self.ns_prefix_ = ns_prefix
-    def get_username(self):
-        return self.username
-    def set_username(self, username):
-        self.username = username
     def get_inner01(self):
         return self.inner01
     def set_inner01(self, inner01):
         self.inner01 = inner01
+    def get_inner02(self):
+        return self.inner02
+    def set_inner02(self, inner02):
+        self.inner02 = inner02
     def _hasContent(self):
         if (
-            self.username is not None or
-            self.inner01 is not None
+            self.inner01 is not None or
+            self.inner02 is not None
         ):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_1', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType01_1')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType00_1', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType00_1')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'oneperType01_1':
+        if self.original_tagname_ is not None and name_ == 'oneperType00_1':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType01_1')
+        self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType00_1')
         if self._hasContent():
             outfile.write('>%s' % (eol_, ))
-            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType01_1', pretty_print=pretty_print)
+            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType00_1', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType01_1'):
+    def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType00_1'):
         pass
-    def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_1', fromsubclass_=False, pretty_print=True):
+    def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType00_1', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.username is not None:
-            namespaceprefix_ = self.username_nsprefix_ + ':' if (UseCapturedNS_ and self.username_nsprefix_) else ''
-            showIndent(outfile, level, pretty_print)
-            outfile.write('<%susername>%s</%susername>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.username), input_name='username')), namespaceprefix_ , eol_))
         if self.inner01 is not None:
             namespaceprefix_ = self.inner01_nsprefix_ + ':' if (UseCapturedNS_ and self.inner01_nsprefix_) else ''
             self.inner01.export(outfile, level, namespaceprefix_, namespacedef_='', name_='inner01', pretty_print=pretty_print)
+        if self.inner02 is not None:
+            namespaceprefix_ = self.inner02_nsprefix_ + ':' if (UseCapturedNS_ and self.inner02_nsprefix_) else ''
+            self.inner02.export(outfile, level, namespaceprefix_, namespacedef_='', name_='inner02', pretty_print=pretty_print)
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
         if SaveElementTreeNode:
@@ -1115,120 +1114,21 @@ class oneperType01_1(GeneratedsSuper):
     def _buildAttributes(self, node, attrs, already_processed):
         pass
     def _buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'username':
-            value_ = child_.text
-            value_ = self.gds_parse_string(value_, node, 'username')
-            value_ = self.gds_validate_string(value_, node, 'username')
-            self.username = value_
-            self.username_nsprefix_ = child_.prefix
-        elif nodeName_ == 'inner01':
-            obj_ = oneperType01_2.factory(parent_object_=self)
+        if nodeName_ == 'inner01':
+            obj_ = oneperType01_1.factory(parent_object_=self)
             obj_.build(child_, gds_collector_=gds_collector_)
             self.inner01 = obj_
             obj_.original_tagname_ = 'inner01'
-# end class oneperType01_1
-
-
-class oneperType01_2(GeneratedsSuper):
-    __hash__ = GeneratedsSuper.__hash__
-    member_data_items_ = [
-        MemberSpec_('userdescription', 'xs:string', 0, 0, {'name': 'userdescription', 'type': 'xs:string'}, None),
-    ]
-    subclass = None
-    superclass = None
-    def __init__(self, userdescription=None, gds_collector_=None, **kwargs_):
-        self.gds_collector_ = gds_collector_
-        self.gds_elementtree_node_ = None
-        self.original_tagname_ = None
-        self.parent_object_ = kwargs_.get('parent_object_')
-        self.ns_prefix_ = None
-        self.userdescription = userdescription
-        self.userdescription_nsprefix_ = None
-    def factory(*args_, **kwargs_):
-        if CurrentSubclassModule_ is not None:
-            subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, oneperType01_2)
-            if subclass is not None:
-                return subclass(*args_, **kwargs_)
-        if oneperType01_2.subclass:
-            return oneperType01_2.subclass(*args_, **kwargs_)
-        else:
-            return oneperType01_2(*args_, **kwargs_)
-    factory = staticmethod(factory)
-    def get_ns_prefix_(self):
-        return self.ns_prefix_
-    def set_ns_prefix_(self, ns_prefix):
-        self.ns_prefix_ = ns_prefix
-    def get_userdescription(self):
-        return self.userdescription
-    def set_userdescription(self, userdescription):
-        self.userdescription = userdescription
-    def _hasContent(self):
-        if (
-            self.userdescription is not None
-        ):
-            return True
-        else:
-            return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_2', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType01_2')
-        if imported_ns_def_ is not None:
-            namespacedef_ = imported_ns_def_
-        if pretty_print:
-            eol_ = '\n'
-        else:
-            eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'oneperType01_2':
-            name_ = self.original_tagname_
-        if UseCapturedNS_ and self.ns_prefix_:
-            namespaceprefix_ = self.ns_prefix_ + ':'
-        showIndent(outfile, level, pretty_print)
-        outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
-        already_processed = set()
-        self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType01_2')
-        if self._hasContent():
-            outfile.write('>%s' % (eol_, ))
-            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType01_2', pretty_print=pretty_print)
-            showIndent(outfile, level, pretty_print)
-            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
-        else:
-            outfile.write('/>%s' % (eol_, ))
-    def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType01_2'):
-        pass
-    def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_2', fromsubclass_=False, pretty_print=True):
-        if pretty_print:
-            eol_ = '\n'
-        else:
-            eol_ = ''
-        if self.userdescription is not None:
-            namespaceprefix_ = self.userdescription_nsprefix_ + ':' if (UseCapturedNS_ and self.userdescription_nsprefix_) else ''
-            showIndent(outfile, level, pretty_print)
-            outfile.write('<%suserdescription>%s</%suserdescription>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.userdescription), input_name='userdescription')), namespaceprefix_ , eol_))
-    def build(self, node, gds_collector_=None):
-        self.gds_collector_ = gds_collector_
-        if SaveElementTreeNode:
-            self.gds_elementtree_node_ = node
-        already_processed = set()
-        self.ns_prefix_ = node.prefix
-        self._buildAttributes(node, node.attrib, already_processed)
-        for child in node:
-            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
-            self._buildChildren(child, node, nodeName_, gds_collector_=gds_collector_)
-        return self
-    def _buildAttributes(self, node, attrs, already_processed):
-        pass
-    def _buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'userdescription':
-            value_ = child_.text
-            value_ = self.gds_parse_string(value_, node, 'userdescription')
-            value_ = self.gds_validate_string(value_, node, 'userdescription')
-            self.userdescription = value_
-            self.userdescription_nsprefix_ = child_.prefix
-# end class oneperType01_2
+        elif nodeName_ == 'inner02':
+            obj_ = oneperType01_2.factory(parent_object_=self)
+            obj_.build(child_, gds_collector_=gds_collector_)
+            self.inner02 = obj_
+            obj_.original_tagname_ = 'inner02'
+# end class oneperType00_1
 
 
 GDSClassesMapping = {
-    'root01': oneperType01_1,
+    'root00': oneperType00_1,
 }
 
 
@@ -1275,8 +1175,8 @@ def parse(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType01_1'
-        rootClass = oneperType01_1
+        rootTag = 'oneperType00_1'
+        rootClass = oneperType00_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     CapturedNsmap_, namespacedefs = get_required_ns_prefix_defs(rootNode)
@@ -1307,8 +1207,8 @@ def parseEtree(inFileName, silence=False, print_warnings=True,
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType01_1'
-        rootClass = oneperType01_1
+        rootTag = 'oneperType00_1'
+        rootClass = oneperType00_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     if mapping is None:
@@ -1353,8 +1253,8 @@ def parseString(inString, silence=False, print_warnings=True):
     gds_collector = GdsCollector_()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType01_1'
-        rootClass = oneperType01_1
+        rootTag = 'oneperType00_1'
+        rootClass = oneperType00_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     if not SaveElementTreeNode:
@@ -1381,8 +1281,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType01_1'
-        rootClass = oneperType01_1
+        rootTag = 'oneperType00_1'
+        rootClass = oneperType00_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     # Enable Python to collect the space used by the DOM.
@@ -1390,8 +1290,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
         doc = None
         rootNode = None
 ##     if not silence:
-##         sys.stdout.write('#from oneperType01_1One import *\n\n')
-##         sys.stdout.write('import oneperType01_1One as model_\n\n')
+##         sys.stdout.write('#from oneperType00_1One import *\n\n')
+##         sys.stdout.write('import oneperType00_1One as model_\n\n')
 ##         sys.stdout.write('rootObj = model_.rootClass(\n')
 ##         rootObj.exportLiteral(sys.stdout, 0, name_=rootTag)
 ##         sys.stdout.write(')\n')
@@ -1421,6 +1321,11 @@ RenameMappings_ = {
 
 }
 __all__ = [
+    "oneperType00_1",
     "oneperType01_1",
-    "oneperType01_2"
+    "oneperType01_2",
+    "oneperType02_1",
+    "oneperType02_2",
+    "oneperType03_1",
+    "oneperType03_2"
 ]
